/***************************************************************************
    begin       : Mon Mar 01 2004
    copyright   : (C) 2020 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef AH_JOB_COMMIT_ACCOUNT_H
#define AH_JOB_COMMIT_ACCOUNT_H

#include "aqhbci/joblayer/job_l.h"


void AH_Job_Commit_Accounts(AH_JOB *j);



#endif




